@@ -1,20 +1,33 @@
+import IPython.display
 from ipykernel.zmqshell import ZMQInteractiveShell
-from .output import OutputStream, Output
+from .output import OutputStreamsSetter, OutputText, OutputTextStyled
+
+import sys
 
 
 class IpythonWatcher(object):
     def __init__(self, ip: ZMQInteractiveShell):
         self.shell = ip
+        self._save_prev_outputs()
+
+    def _save_prev_outputs(self):
+        self.stdout = sys.stdout
+        self.stderr = sys.stderr
+
+    def _activate_prev_outputs(self):
+        sys.stdout = self.stdout
+        sys.stderr = self.stderr
 
     def pre_execute(self):
-        stream = OutputStream(Output())
+        self._save_prev_outputs()
+        stream = OutputStreamsSetter(stdout=OutputText(kind='stdout'), stderr=OutputText(kind='stderr'))
         stream.activate()
 
     def pre_run_cell(self, info):
         ...
 
     def post_execute(self):
-        ...
+        self._activate_prev_outputs()
 
     def post_run_cell(self, result):
         ...
@@ -35,3 +48,11 @@ def load_ipython_extension(ipython):
     """
     from .magic import IgogoMagic
     ipython.register_magics(IgogoMagic)
+
+def _modify_styles():
+    IPython.display.display_html(IPython.display.HTML("""
+    <style>
+        div.output_text { padding: 0; }
+        div.output_text pre:empty { padding: 0; }
+    </style>
+    """))
